SpatialPointsMeteorology-class: Class "SpatialPointsMeteorology"
Description
An S4 class that represents a set of points with meteorology data series.
Usage
# S4 method for SpatialPointsMeteorology,ANY,ANY
[(x, i, j, ..., drop = TRUE)
# S4 method for SpatialPointsMeteorology
show(object)
Objects from the Class
Objects can be created by calls of the form new("SpatialPointsMeteorology", ...), or by calls to the function SpatialPointsMeteorology.
Slots
dates:
Object of class "Date" describing the time period for which meteorological estimates are available.
data:
A vector of "data.frame" objects, each one corresponding to one spatial point.
coords:
Object of class "matrix" with the spatial coordinates.
bbox:
Object of class "matrix" with the boundary box.
proj4string:
Object of class "CRS" with the projection string.
Extends
Class "SpatialPoints", directly.
Class "Spatial", by class "SpatialPoints", distance 2.
Arguments
- x,object
SpatialPointsMeteorology object
- i
row indices
- j
column indices
- drop
see Extract
- ...
indices passed through
Author
Miquel De Cáceres Ainsa, CREAF
See Also
SpatialPointsTopography-class, SpatialPoints-class
Examples
Run this code#Structure of the S4 object
showClass("SpatialPointsMeteorology")
Run the code above in your browser using DataLab